Position

Struct Position 

pub(super) struct Position {
    input_len: Length,
    position: Length,
}
State tracker for the current position in the input.

Fields

input_len: Length

Input length (in bytes after Base64 decoding).

position: Length

Position in the input buffer (in bytes after Base64 decoding).

Implementations

Source

impl Position

pub(super) fn new(input_len: Length) -> Self

Create a new position tracker with the given overall length.

pub(super) fn input_len(&self) -> Length

Get the input length.

pub(super) fn current(&self) -> Length

Get the current position.

pub(super) fn advance(&mut self, amount: Length) -> Result<Length>

Advance the current position by the given amount.

Returns

The new current position.

pub(super) fn split_nested(&mut self, len: Length) -> Result<Resumption>

Split a nested position tracker of the given size.

Returns

A Resumption value which can be used to continue parsing the outer message.

pub(super) fn resume_nested(&mut self, resumption: Resumption)

Resume processing the rest of a message after processing a nested inner portion.