pub(super) struct Position {
input_len: Length,
position: Length,
}Expand description
State tracker for the current position in the input.
Fields
input_len: LengthInput length (in bytes after Base64 decoding).
position: LengthPosition in the input buffer (in bytes after Base64 decoding).
Implementations
Sourceimpl Position
impl Position
Sourcepub(super) fn new(input_len: Length) -> Self
pub(super) fn new(input_len: Length) -> Self
Create a new position tracker with the given overall length.
Sourcepub(super) fn split_nested(&mut self, len: Length) -> Result<Resumption>
pub(super) fn split_nested(&mut self, len: Length) -> Result<Resumption>
Split a nested position tracker of the given size.
Returns
A Resumption value which can be used to continue parsing the outer message.
Sourcepub(super) fn resume_nested(&mut self, resumption: Resumption)
pub(super) fn resume_nested(&mut self, resumption: Resumption)
Resume processing the rest of a message after processing a nested inner portion.